@@ -2,7 +2,7 @@
 #
 # COPYRIGHT:
 #
-# This software is Copyright (c) 1996-2011 Best Practical Solutions, LLC
+# This software is Copyright (c) 1996-2012 Best Practical Solutions, LLC
 #                                          <sales@bestpractical.com>
 #
 # (Except where explicitly superseded by other copyright notices)
@@ -69,7 +69,6 @@ RT::Base
 
 =cut
 
-# {{{ sub CurrentUser 
 
 =head2 CurrentUser
 
@@ -100,20 +99,9 @@ sub CurrentUser {
             if ref $self->{'user'} && $self->{'user'} == $self;
     }
 
-    unless ( ref $self->{'user'} && $self->{'user'}->isa('RT::CurrentUser') ) {
-        my $msg = "$self was created without a CurrentUser."
-            ." Any RT object which is subclass of RT::Base must be created"
-            ." with a RT::CurrentUser or a RT::User object as the first argument.";
-        $msg .= "\n". Carp::longmess() if @_;
-
-        $RT::Logger->error( $msg );
-        return $self->{'user'} = undef;
-    }
-
     return ( $self->{'user'} );
 }
 
-# }}}
 
 sub OriginalUser {
     my $self = shift;
@@ -171,7 +159,7 @@ sub _ImportOverlays {
     for my $type (qw(Overlay Vendor Local)) {
         my $filename = $package."_".$type.".pm";
         eval { require $filename };
-        die $@ if ($@ && $@ !~ qr{^Can't locate $filename});
+        die $@ if ($@ && $@ !~ m{^Can't locate $filename});
     }
 }
 
